OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Imeongezwa kwa vipendwa",
    "Removed from favorites" : "Imeondolewa kutoka vipendwa",
    "You added {file} to your favorites" : "Umeongeza {file}kwa vipendwa vyako",
    "You removed {file} from your favorites" : "Umeondoa {file}kwenye vipendwa vyako",
    "Favorites" : "Vinavyopendwa",
    "File changes" : "Mabadiliko ya faili",
    "Created by {user}" : "Imetengenezwa na {user}",
    "Changed by {user}" : "Imebadilishwa na {user}",
    "Deleted by {user}" : "Imefutwa na {user}",
    "Restored by {user}" : "Imehifadhiwa na {user}",
    "Renamed by {user}" : "Imepewa jina upya na {user}",
    "Moved by {user}" : "Imesogezwa na {user}",
    "\"remote account\"" : "\"akaunti ya mbali\"",
    "You created {file}" : "Umetengeneza {file}",
    "You created an encrypted file in {file}" : "Umeunda faili iliyosimbwa kwa njia fiche katika {file}",
    "{user} created {file}" : "{user} ameunda {file}",
    "{user} created an encrypted file in {file}" : "{user}ameunda faili iliyosimbwa kwa njia fiche katika {file}",
    "{file} was created in a public folder" : "{file}ilitengenezwa katika kisanduku cha umma",
    "You changed {file}" : "Umebadilisha {file}",
    "You changed an encrypted file in {file}" : "Umebadilisha faili iliyosimbwa kwa njia fiche katika {file}",
    "{user} changed {file}" : "{user} amebadili {file}",
    "{user} changed an encrypted file in {file}" : "{user}amebadili faili iliyosimbwa kwa njia fiche katika {file}",
    "You deleted {file}" : "Umefuta {file}",
    "You deleted an encrypted file in {file}" : "Umefuta faili iliyosimbwa kwa njia fiche katika {file}",
    "{user} deleted {file}" : "{user} amefuta {file}",
    "{user} deleted an encrypted file in {file}" : "{user} amefuta faili iliyosimbwa kwa njia fiche katika {file}",
    "You restored {file}" : "Umehifadhi upya {file}",
    "{user} restored {file}" : "{user} amehifadhi upya {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Umeita jina upya {oldfile}(iliyofichwa)kwenda {newfile} (iliyofichwa)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Umeita jina upya {oldfile}(iliyofichwa)kwenda{newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Umeita jina upya {oldfile}kwenda{newfile}(iliyofichwa)",
    "You renamed {oldfile} to {newfile}" : "Umeita jina upya {oldfile}hadi{newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user}ameita jina upya{oldfile}(iliyofichwa) hadi {newfile} (iliyofichwa)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user}ameita jina upya{oldfile}(iliyofichwa) hadi{newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}ameita jina upya{oldfile}hadi{newfile}(iliyofichwa)",
    "{user} renamed {oldfile} to {newfile}" : "{user}ameita jina upya {oldfile}hadi{newfile}",
    "You moved {oldfile} to {newfile}" : "Umeondoa {oldfile}hadi{newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user}amesogeza {oldfile}hadi{newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Faili limeongezwa kwenye au limeondolewa kutoka <strong>vipendwa</strong>",
    "Files" : "Mafaili",
    "A file or folder has been <strong>changed</strong>" : "Faili au kisanduku kime<strong>badilishwa</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Faili pendwa au kisanduku kime<strong>badilishwa</strong>",
    "Failed to authorize" : "Imeshindwa kuidhinisha",
    "Invalid folder path" : "Njia ya kisanduku si halali",
    "Folder not found" : "Kisanduku hakipatikani",
    "The file cannot be found" : "Faili haliwezi kupatikana",
    "The destination path does not exist: %1$s" : "Njia lengwa haipo %1$s",
    "You do not have permission to create a file at the specified location" : "Huna ruhusa kuunda faili katika eneo lililobainishwa",
    "The file could not be converted." : "Faili halikuweza kubadilishwa",
    "Could not get relative path to converted file" : "Haikuweza kupata njia sawia ya faili lililobadilishwa",
    "Limit must be a positive integer." : "Kikomo lazima kiwe nambari chanya.",
    "The replacement character may only be a single character." : "Herufi mbadala inaweza tu kuwa herufi moja.",
    "Filename sanitization already started." : "Usafishaji wa jina la faili tayari umeanza.",
    "No filename sanitization in progress." : "Hakuna maendeleo ya utakaso wa jina la faili.",
    "Favorite files" : "Faili pendwa",
    "No favorites" : "Hakuna vipendwa",
    "More favorites" : "Vipendwa zaidi",
    "Accept" : "Kubali",
    "Reject" : "Kataa",
    "Incoming ownership transfer from {user}" : "Uhamisho wa umiliki unaoingia kutoka {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Je unataka kukubali {path}?\n\nKubmbuka: Mchakato wa uhamisho baada ya kukubali unaweza kuchukua mpaka saa 1",
    "Ownership transfer denied" : "Uhamisho wa umiliki umekataliwa",
    "Your ownership transfer of {path} was denied by {user}." : "Uhamisho wa umiliki wako wa {path}umekataliwa na {user}",
    "Ownership transfer failed" : "Uhamisho wa umiliki umeshindikana",
    "Your ownership transfer of {path} to {user} failed." : "Uhamisho wa umiliki wako wa {path}kwenda {user}umeshindikana",
    "The ownership transfer of {path} from {user} failed." : "Uhamisho wa umiliki wa {path}kutoka {user}umeshindikana",
    "Ownership transfer done" : "Uhamisho wa umiliki umefanyika",
    "Your ownership transfer of {path} to {user} has completed." : "Uhamisho wako wa umiliki wa {path}kwenda {user}umekamilika",
    "The ownership transfer of {path} from {user} has completed." : "Uhamisho wa umiliki wa {path}kutoka{user}umekamilika",
    "in %s" : "Katika %s",
    "Transferred from %1$s on %2$s" : "Imehamishwa kutoka %1$skatika%2$s",
    "File Management" : "Usimamizi wa faili",
    "Home" : "Nyumbani",
    "Target folder does not exist any more" : "Kisanduku kilicholengwa hakipo tena",
    "Reload current directory" : "Pakia upya kitabu cha orodha ya sasa",
    "Go to the \"{dir}\" directory" : "Nenda kwenye {dir}kitabu cha orodha",
    "Current directory path" : "Njia ya kitabu cha orodha ya sasa",
    "Share" : "Shirikisha",
    "Your have used your space quota and cannot upload files anymore" : "Umetumia nafasi yako kwa upendeleo na huwezi kupakia faili zaidi",
    "You do not have permission to upload or create files here." : "Huna ruhusa kupakia au kutengeneza faili hapa",
    "Drag and drop files here to upload" : "Sogeza na udondoshe faili hapa ili upakie",
    "Favorite" : "Kipendwa",
    "Back" : "Rudi",
    "Toggle selection for file \"{displayName}\"" : "Geuza uteuzi wa faili \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Geuza uteuzi wa kisanduku \"{displayName}\"",
    "File is loading" : "Faili inapakia",
    "Folder is loading" : "Kisanduku kinapakia",
    "Filename" : "Jina la faili",
    "Folder name" : "Jina la kisanduku",
    "This node is unavailable" : "Nodi hii haipatikani",
    "Another entry with the same name already exists." : "Ingizo lingine lenye jina sawasawa lipo tayari",
    "Invalid filename." : "Majina ya faili si sahihi",
    "Rename file" : "Badili jina la faili",
    "Folder" : "Kisanduku",
    "Unknown file type" : "Aina ya faili isiyojulikana",
    "{ext} image" : "{ext}picha",
    "{ext} video" : "{ext}picha mjongeo",
    "{ext} audio" : "{ext}sauti",
    "{ext} text" : "{ext}maandishi",
    "Pending" : "Inasubiri",
    "Unknown date" : "Tarehe isiyojulikana",
    "Active filters" : "Vichujio vinavyotumika",
    "Remove filter" : "Ondoa kichujio",
    "Today" : "Leo",
    "Last 7 days" : "Siku 7 zilizopita",
    "Last 30 days" : "Siku 30 zilizopita",
    "This year ({year})" : "Mwaka huu ({year})",
    "Last year ({year})" : "Mwaka uliopita ({year})",
    "Custom date range" : "Safu ya tarehe maalum",
    "Search everywhere" : "Tafuta kila mahali",
    "Documents" : "Nyaraka",
    "Spreadsheets" : "Lahajedwali",
    "Presentations" : "Uwasilishaji",
    "PDFs" : "PDFs",
    "Folders" : "Visanduku",
    "Audio" : "Sauti",
    "Images" : "Picha",
    "Videos" : "Picha mjongeo",
    "Filters" : "Vichujio",
    "Appearance" : "Mwonekano",
    "Show hidden files" : "Onesha mafaili yaliyofichwa",
    "Show file type column" : "Onyesha safu wima ya aina ya faili",
    "Show file extensions" : "Onesha viendelezi vyote",
    "Crop image previews" : "Punguza onyesho la kukagua picha",
    "General" : "Kuu",
    "Sort favorites first" : "Chagua za upendeleo kwanza",
    "Sort folders before files" : "Chagua vikasha kabla ya mafaili",
    "Enable folder tree view" : "Washa mwonekano wa mti wa folda",
    "Default view" : "Mwonekano chaguomsingi",
    "All files" : "Faili zote",
    "Personal files" : "Faili binafsi",
    "Additional settings" : "Mipangilio ya nyongeza",
    "Actions" : "Utendekaji",
    "File actions" : "Matendo ya faili",
    "Selection" : "Machaguo",
    "Select all files" : "Chagua faili zote",
    "Deselect all" : "Acha kuchagua zote",
    "Select or deselect" : "Chagua au ondoa chaguo",
    "Select a range" : "Chagua anuwai",
    "Navigation" : "Uendeshaji",
    "Go to parent folder" : "Nenda kwenye folda kuu",
    "Go to file above" : "Nenda kwenye faili juu",
    "Go to file below" : "Nenda kwenye faili chini",
    "Go left in grid" : "Nenda kushoto katika grid",
    "Go right in grid" : "Nenda kulia katika grid",
    "View" : "Angalia",
    "Toggle grid view" : "Badilisha mwonekano wa gridi",
    "Show those shortcuts" : "Onesha mikato hiyo",
    "Warnings" : "Maonyo",
    "Warn before changing a file extension" : "Onya kabla ya kubadilisha kiendelezi cha faili",
    "Warn before deleting a file" : "Onya kabla ya kufuta faili",
    "WebDAV URL" : "WavutiDAV URL",
    "Create an app password" : "Unda nenosiri la programu",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Inahitajika kwa uthibitishaji wa WebDAV kwa sababu Uthibitishaji wa Mambo Mbili umewezeshwa kwa akaunti hii.",
    "How to access files using WebDAV" : "Jinsi ya kupata faili kwa kutumia WebDAV",
    "Total rows summary" : "Muhtasari wa jumla ya safu mlalo",
    "Toggle selection for all files and folders" : "Geuza uteuzi wa faili na visanduku vyote",
    "Name" : "Jina",
    "File type" : "Aina ya faili",
    "Size" : "Ukubwa",
    "Modified" : "Iliyoboreshwa",
    "{displayName}: failed on some elements" : "{displayName}: Ilifeli kwenye vipengele vingine",
    "{displayName}: done" : "{displayName}: imefanyika",
    "{displayName}: failed" : "{displayName}: imeshindwa",
    "(selected)" : "(iliyochaguliwa)",
    "List of files and folders." : "Orodha ya faili na visanduku",
    "You have used your space quota and cannot upload files anymore." : "Umetumia mgao wako wa nafasi na huwezi kupakia faili tena.",
    "Column headers with buttons are sortable." : "Vichwa vya safu wima vilivyo na vifungo vinaweza kupangwa.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Orodha hii haijatolewa kikamilifu kwa sababu za utendaji. Faili zitatolewa unapopitia orodha.",
    "File not found" : "Faili halipatikani",
    "_{count} selected_::_{count} selected_" : ["{count} selected","{count} iliyochaguliwa"],
    "Search everywhere …" : "Tafuta kila mahali ...",
    "Search here …" : "Tafuta hapa ...",
    "Search scope options" : "Chaguo za upeo wa utafutaji",
    "Search here" : "Tafuta hapa",
    "Owner" : "Mmiliki",
    "{usedQuotaByte} used" : "{usedQuotaByte}imetumika",
    "{used} of {quota} used" : "{used} ya {quota}imetumika",
    "{relative}% used" : "{relative}% imetumika",
    "Could not refresh storage stats" : "Haikuweza kuonesha upya takwimu za hifadhi",
    "Your storage is full, files can not be updated or synced anymore!" : "Hifadhi yako imejaa, faili haziwezi kusasishwa au kusawazishwa tena!",
    "Storage information" : "Taarifa za uhifadhi",
    "Storage quota" : "Kiasi cha uhifadhi",
    "New folder" : "Kisanduku kipya",
    "Create new folder" : "Tengeneza kisanduku kipya",
    "This name is already in use." : "Jina hili liko katika matumizi tayari",
    "Create" : "Tengeneza",
    "Files starting with a dot are hidden by default" : "Faili zinazoanza na nukta zimefichwa kwa chaguo-msingi",
    "Failed to start filename sanitization." : "Imeshindwa kuanza usafishaji wa jina la faili.",
    "Failed to refresh filename sanitization status." : "Imeshindwa kuonyesha upya hali ya utakaso wa jina la kushindwa.",
    "Filename sanitization in progress." : "Usafishaji wa jina la faili unaendelea.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Kwa sasa {processedUsers} kati ya akaunti za {totalUsers} tayari zimechakatwa.",
    "Preparing …" : "Inaandaa ...",
    "Refresh" : "Onyesha upya",
    "All files have been santized for Windows filename support." : "Faili zote zimesafishwa kwa usaidizi wa jina la faili la Windows.",
    "Some files could not be sanitized, please check your logs." : "Baadhi ya faili hazikuweza kusafishwa, tafadhali angalia kumbukumbu zako.",
    "Sanitization errors" : "Makosa ya usafishaji",
    "Not sanitized filenames" : "Majina ya faili hayajasafishwa",
    "Windows filename support has been enabled." : "Usaidizi wa jina la faili la Windows umewezeshwa.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Ingawa hii inazuia watumiaji kuunda faili mpya na majina ya faili ambayo hayatumiki, faili zilizopo bado hazijabadilishwa jina na kwa hivyo bado zinaweza kuvunja usawazishaji kwenye Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Unaweza kuanzisha jina jipya la faili zilizo na majina batili ya faili, hii itafanywa chinichini na inaweza kuchukua muda.",
    "Please note that this may cause high workload on the sync clients." : "Tafadhali kumbuka kuwa hii inaweza kusababisha mzigo mkubwa wa kazi kwenye viteja vya kusawazisha.",
    "Limit" : "Kikomo",
    "This allows to configure how many users should be processed in one background job run." : "Hii inaruhusu kusanidi ni watumiaji wangapi wanapaswa kuchakatwa katika kazi moja ya usuli.",
    "Sanitize filenames" : "Takasa majina ya faili",
    "(starting)" : "(inaanza)",
    "Fill template fields" : "Jaza sehemu za violezo",
    "Submitting fields …" : "Inawasilisha sehemu  …",
    "Submit" : "Wasilisha",
    "Choose a file or folder to transfer" : "Chagua faili au kisanduku cha kuhamisha",
    "Transfer" : "Hamisha",
    "Transfer {path} to {userid}" : "Hamisha {path}mpaka {userid}",
    "Invalid path selected" : "Njia iliyochaguliwa si halali",
    "Unknown error" : "Hitilafu isiyojulikana",
    "Ownership transfer request sent" : "Ombi la uhamisho wa umiliki limetumwa",
    "Cannot transfer ownership of a file or folder you do not own" : "Haiwezi kuhamisha umiliki wa faili au kisanduku usichomiliki",
    "Transfer ownership of a file or folder" : "Hamisha umiliki wa faili au kisanduku",
    "Choose file or folder to transfer" : "Chagua faili au kisanduku cha kuhamisha",
    "Change" : "Badili",
    "New owner" : "Mmiliki mpya",
    "Keep {old}" : "Weka {old}",
    "Keep without extension" : "Weka bila ongezeko",
    "Use {new}" : "Tumia {new}",
    "Remove extension" : "Ondoa ongezeko",
    "Change file extension" : "Badili ongezeko la faili",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Kubadilisha kiendelezi cha faili kutoka \"{old}\" hadi \"{new}\" kunaweza kufanya faili isisomeke.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Kuondoa kiendelezi cha faili \"{old}\" kunaweza kufanya faili isisomeke.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Kuongeza kiendelezi cha faili \"{new}\" kunaweza kufanya faili isisomeke.",
    "Do not show this dialog again." : "Usioneshe mazungumzo haya tena",
    "Cancel" : "Sitisha",
    "Rename" : "Ipe jina jipya",
    "Select file or folder to link to" : "Chagua faili au kisanduku cha kuunga kwa",
    "Choose {file}" : "Chagua {file}",
    "Files settings" : "Mipangilio ya faili",
    "Switch to list view" : "Badili hadi mwonekano wa orodha",
    "Switch to grid view" : "Badili hadi mwonekano wa gridi",
    "The file could not be found" : "Faili halikupatikana",
    "Upload was cancelled by user" : "Upakiaji ulisitishwa na mtumiaji",
    "Not enough free space" : "Hakuna eneo huru la kutosha",
    "Operation is blocked by access control" : "Uendeshaji umezuiwa na udhibiti wa ufikiaji",
    "Error during upload: {message}" : "Hitilafu wakati wa kupakia: {message}",
    "Error during upload, status code {status}" : "Hitilafu wakati wa kupakia, msimbo wa hali {status}",
    "Unknown error during upload" : "Hitilafu isiyojulikana wakati wa kupakia",
    "Loading current folder" : "Inapakia faili ya sasa",
    "Retry" : "Jaribu tene",
    "No files in here" : "Hakuna faili hapa",
    "Upload some content or sync with your devices!" : "Pakia baadhi ya maudhui au usawazishe na vifaa vyako!",
    "Go back" : "Rudi nyuma",
    "Views" : "Mionekano",
    "Loading …" : "Inapakia  …",
    "Your files" : "Mafaili yako",
    "Open in files" : "Fungua ndani ya faili",
    "File cannot be accessed" : "Faili haliwezi kufikika",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Faili haikupatikana au huna ruhusa ya kuitazama. Uliza mtumaji kuishirikisha.",
    "No search results for “{query}”" : "Hakuna matokeo ya utafutaji kwa {query}",
    "Search for files" : "Tafuta faili",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ruhusu kuzuia majina ya faili ili kuhakikisha kuwa faili zinaweza kusawazishwa na wateja wote. Kwa chaguo-msingi, majina yote ya faili ni halali katika POSIX (e.g. Linux or macOS) zinaruhusiwa.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Baada ya kuruhusu majina ya faili yanayooana na Windows, faili zilizopo haziwezi kubadilishwa tena lakini zinaweza kubadilishwa kuwa majina mapya halali na mmiliki wao.",
    "Failed to toggle Windows filename support" : "Failed to toggle Windows filename support",
    "Files compatibility" : "Utengamano wa faili",
    "Enforce Windows compatibility" : "Tekeleza utangamano wa windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Hii itazuia majina ya faili ambayo si halali kwenye mifumo ya Windows, kama vile kutumia majina yaliyohifadhiwa au herufi maalum. Lakini hii haitatekeleza utangamano wa unyeti wa kesi.",
    "Blank" : "Mabano",
    "Unable to create new file from template" : "Imeshindwa kutengeneza faili jipya kutoka kwenye sampuli/kiolezo",
    "Pick a template for {name}" : "Chagua sampuli/kiolezo kwa {name}",
    "Create a new file with the selected template" : "Tengeneza faili jipya na kiolezo/sampuli iliyochaguliwa",
    "Creating file" : "Inatengeneza faili",
    "Save as {displayName}" : "Hifadhi kama {displayName}",
    "Save as …" : "Hifadhi kama ...",
    "Converting files …" : "Inabadilisha faili …",
    "Failed to convert files: {message}" : "Imeshindwa kugeuza faili {message}",
    "All files failed to be converted" : "Faili zote zimeshindwa kugeuzwa",
    "One file could not be converted: {message}" : "Faili moja isingeweza kugeuzwa {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n file could not be converted","%n faili hazikuweza kubadilishwa"],
    "_%n file converted_::_%n files converted_" : ["%n file converted","%n faili zilizobadilishwa"],
    "Files converted" : "Faili zimebadilishwa",
    "Failed to convert files" : "Imeshindwa kugeuza faili",
    "Converting file …" : "Inabadilisha faili  …",
    "File successfully converted" : "Faili imegeuzwa kikamilifu",
    "Failed to convert file: {message}" : "Imeshindwa kugeuza faili {message}",
    "Failed to convert file" : "Imeshindwa kugeuza faili",
    "Delete" : "Futa",
    "Leave this share" : "Ondoa ushirikishaji huu",
    "Leave these shares" : "Ondoa shiriki hizi",
    "Disconnect storage" : "Achanisha uhifadhi",
    "Disconnect storages" : "Achanisha hifadhi",
    "Delete permanently" : "Futa moja kwa moja",
    "Delete and unshare" : "Futa na usishirikishe",
    "Delete file" : "Futa faili",
    "Delete files" : "Futa faili",
    "Delete folder" : "Futa kisanduku",
    "Delete folders" : "Futa visanduku",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","Unakaribia kufuta vipengee {count}kabisa"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","Unakaribia kufuta vipengee{count}"],
    "Confirm deletion" : "Thibitisha ufutaji",
    "Download" : "Pakua",
    "The requested file is not available." : "Faili iliyoombwa haipatikani.",
    "The requested files are not available." : "Faili zilizoombwa hazipatikani.",
    "Add to favorites" : "Ongeza kwenye pendwa",
    "Remove from favorites" : "Ondoa kutoka katika pendwa",
    "Add or remove favorite" : "Ongeza au ondoa vipendwa",
    "Move" : "Hamisha",
    "Copy" : "Nakili",
    "Move or copy" : "Hamisha au nakili",
    "Destination is not a folder" : " Lengwa si folda",
    "This file/folder is already in that directory" : "Faili/folda hii tayari iko kwenye saraka hiyo",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Huwezi kuhamisha faili/folda kwenye yenyewe au kwenye folda yenyewe",
    "A file or folder with that name already exists in this folder" : "Faili au kisanduku chenye jina hilo tayari kipo katika kisanduku hiki",
    "The files are locked" : "Faili zimezuiliwa",
    "The file does not exist anymore" : "Faili halipo tena",
    "Moving \"{source}\" to \"{destination}\" …" : "Inahamisha \"{source}\" hadi \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Inanakili \"{source}\" hadi \"{destination}\" …",
    "Choose destination" : "Chagua eneo lengwa",
    "Copy to {target}" : "Nakili kwenda {target}",
    "Move to {target}" : "Hamishia {target}",
    "Move or copy operation failed" : "Operesheni ya kuhamisha au kunakili imeshindikana",
    "Open folder" : "Fungua folda",
    "Open folder {displayName}" : "Fungua kisanduku {displayName}",
    "Open in Files" : "Fungua ndani ya faili",
    "Open locally" : "Fungua kikawaida",
    "Failed to redirect to client" : "Imeshindwa kuielekeza kwa mteja",
    "Open file locally" : "Fungua faili kikawaida",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Sasa faili inapaswa kufunguliwa kwenye kifaa chako. Ikiwa sivyo, tafadhali hakikisha kuwa umesakinisha programu ya eneo-kazi.",
    "Retry and close" : "Jaribu upya kisha funga",
    "Open online" : "Fungua mtandaoni",
    "Details" : "Maelezo ya kina",
    "View in folder" : "Angalia ndani ya kisanduku",
    "Type" : "Aina",
    "Created new folder \"{name}\"" : "Imetengeneza kisanduku kipya \"{name}\"",
    "Unable to initialize the templates directory" : "Haikuweza kuanzisha saraka ya violezo",
    "Create templates folder" : "Imetengeneza kisanduku cha violezo",
    "Templates" : "Violezo",
    "New template folder" : "Kisanduku kipya cha violezo",
    "In folder" : "Ndani ya kisanduku",
    "Search in all files" : "Tafuta katika faili zote",
    "Search in folder: {folder}" : "Tafuta katika kisanduku {folder}",
    "One of the dropped files could not be processed" : "Moja ya faili zilizodondoshwa isingeweza kuchakatwa",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Kivinjari chako hakitumii API ya mfumo wa faili. Orodha hazitapakiwa",
    "No files to upload" : "Hakuna faili la kupakia",
    "Unable to create the directory {directory}" : "Haiwezi kutengeneza orodha {directory}",
    "Some files could not be uploaded" : "Faili kadhaa zisingeweza kupakiwa",
    "Files uploaded successfully" : "Faili zimepakiwa kikamilifu",
    "No files to process" : "Hakuna faili la kuchakata",
    "Files copied successfully" : "Faili limenakiliwa kikamilifu",
    "Files moved successfully" : "Faili limeondolewa kikamilifu",
    "Some files could not be copied" : "Faili baadhi zisingeweza kunakiliwa",
    "Some files could not be moved" : "Faili baadhi zisingeweza kuhamishwa",
    "Conflicts resolution skipped" : "Utatuzi wa migogoro ulirukwa",
    "Upload cancelled" : "Upakiaji umesitishwa",
    "Could not rename \"{oldName}\", it does not exist any more" : "Haikuweza kuita jina jipya \"{oldName}\", halipo tena",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Jina \"{newName}\" tayari linatumika katika kisanduku \"{dir}\". Tafadhali chagua jina tofauti",
    "Could not rename \"{oldName}\"" : "Haikuweza kuita jina jipya \"{oldName}\"",
    "This operation is forbidden" : "Opereshini hii imezuiwa",
    "This folder is unavailable, please try again later or contact the administration" : "Folda hii haipatikani, tafadhali jaribu tena baadaye au uwasiliane na msimamizi",
    "Storage is temporarily not available" : "Uhifadhi haupo kwa muda",
    "Unexpected error: {error}" : "Hitilafu isiyotarajiwa {error}",
    "_%n file_::_%n files_" : ["%n file","%n faili"],
    "_%n folder_::_%n folders_" : ["%n folder","%n visanduku/vikasha"],
    "_%n hidden_::_%n hidden_" : ["%n hidden","%n imefichwa"],
    "Filename must not be empty." : "Jina la faili halipaswi kuwa tupu",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" hairuhusiwi ndani ya jina la faili",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ni jina la akiba na haliruhusiwi kwa majina ya faili",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" si aina ya faili inayoruhusiwa",
    "Filenames must not end with \"{extension}\"." : "Majina ya faili hayapaswi kuishia na \"{extension}\"",
    "List of favorite files and folders." : "Orodha ya faili na visanduku vinanyopendwa",
    "No favorites yet" : "Bado hakuna vinavyopendwa",
    "Files and folders you mark as favorite will show up here" : "Faili na visunduku ulivyoweka alama kama vipendwa vitaonekana hapa",
    "List of your files and folders." : "Orodha ya faili na vikasha vyako",
    "Folder tree" : "Mti wa folda",
    "List of your files and folders that are not shared." : "Orodha ya faili na vikasha ambavyo havijashirikishwa",
    "No personal files found" : "Hakuna faili binafsi zilizopatikana",
    "Files that are not shared will show up here." : "Faili ambazo hazija shirikishwa zitaonekana hapa",
    "Recent" : "Hivi karibuni",
    "List of recently modified files and folders." : "Orodha ya faili na vikasha vilivyoboreshwa hivi karibuni",
    "No recently modified files" : "Hakuna faili zilizoboreshwa hivi karibuni",
    "Files and folders you recently modified will show up here." : "Faili na vikasha ulivyoboresha hivi karibuni vitaonekana hapa",
    "Search" : "Tafuta",
    "Search results within your files." : "Tafuta matokeo katika faili zako",
    "No entries found in this folder" : "Hakuna maingizo yaliyopatikana katika kasha hili",
    "Select all" : "Chagua zote",
    "Upload too large" : "Upakiaji mkubwa mno",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Faili unazojaribu kupakia zinazidi ukubwa wa juu zaidi wa upakiaji wa faili kwenye seva hii.",
    "%1$s (renamed)" : "%1$s (iliyopew jina jipya)",
    "renamed file" : "Faili iliyopewa jina jipya",
    "Upload (max. %s)" : "Pakia (kiwango cha juu. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Baada ya kuwezesha majina ya windows ya faili yanayooana, faili zilizopo haziwezi kurekebishwa tena lakini zinaweza kubadilishwa kuwa majina mapya halali na mmiliki wao.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Pia inawezekana kuhamisha faili kiotomatiki baada ya kuwezesha mpangilio huu, tafadhali rejelea hati kuhusu amri ya occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Imebadili jina \"{oldName}\" mpaka \"{newName}\"",
    "Clear filter" : "Futa kichujio",
    "\"{displayName}\" failed on some elements" : "\"{displayName} imeshindwa katika vipengele kadhaa",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" kitendo cha kundi kimetekelezwa kwa mafanikio",
    "\"{displayName}\" action failed" : "\"{displayName}\" matendo yameshindwa",
    "Submitting fields …" : "Inawasilisha violezo",
    "Shared by link" : "Imeshirikishwa na kiungio",
    "Shared" : "Shirikisha",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" kitendo kimetekelezwa kwa mafanikio",
    "Filter file names …" : "Chuja majina ya faili...",
    "Clipboard is not available" : "Ubao wa kunakili haupatikani",
    "WebDAV URL copied to clipboard" : "WavutiDAV URL umenakiliwa kwenye ubao wa kunakili",
    "Enable the grid view" : "Wezesha mwonekano wa gridi",
    "Enable folder tree" : "Wezesha faili la tatu",
    "WebDAV" : "WavutiDAV",
    "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
    "Use this address to access your Files via WebDAV" : "Tumia anwani hii kufikia Faili zako kupitia WavutiDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ikiwa umewasha 2FA, lazima uunde na utumie nenosiri jipya la programu kwa kubofya hapa",
    "Prevent warning dialogs from open or reenable them." : "Zuia mazungumzo ya onyo yasifunguliwe au uwashe upya.",
    "Show a warning dialog when changing a file extension." : "Onyesha mazungumzo ya onyo unapobadilisha kiendelezi cha faili.",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Speed up your Files experience with these quick shortcuts." : "Ongeza kasi ya utumiaji wa Faili zako kwa njia hizi za mkato za haraka.",
    "Open the actions menu for a file" : "Fungua menyu ya vitendo kwa faili",
    "Rename a file" : "Ita faili jina jipya",
    "Delete a file" : "Futa faili",
    "Favorite or remove a file from favorites" : "Pendwa au ondoa faili kutoka pendwa",
    "Manage tags for a file" : "simamia maoni kwa faili",
    "Deselect all files" : "Usichague faili zote",
    "Select or deselect a file" : "Chagua au usichague faili",
    "Select a range of files" : "Chagua anuwai ya faili",
    "Navigate to the parent folder" : "Nenda kwenye kisanduku kikuu",
    "Navigate to the file above" : "Sogea kwenye faili la juu",
    "Navigate to the file below" : "Sogea kwenye faili la chini",
    "Navigate to the file on the left (in grid mode)" : "Sogea kwenye faili la kushoto (in grid mode)",
    "Navigate to the file on the right (in grid mode)" : "Sogea kwenye faili la kulia ( in grid mode)",
    "Toggle the grid view" : "Geuza mwonekano wa gridi",
    "Open the sidebar for a file" : "Fungua utepe kwa faili",
    "You" : "Wewe",
    "Shared multiple times with different people" : "Imeshirikiwa mara nyingi na watu tofauti",
    "Unable to change the favorite state of the file" : "Haiwezi kubadilisha hali ya faili inayopendwa",
    "Error while loading the file data" : "Hitilafu wakati wa kupakia data za faili",
    "Tags" : "Maoni",
    "Save as …" : "Hifadhi kama",
    "Converting files …" : "Inageuza mafaili",
    "Converting file …" : "Inageuza faili",
    "Deletion cancelled" : "Ufutaji umesitishwa",
    "Edit locally" : "Hariri kikawaida",
    "Moving \"{source}\" to \"{destination}\" …" : "Sogeza \"{source}\" mpaka \"{destination}\"",
    "Copying \"{source}\" to \"{destination}\" …" : "Inanakili \"{source}\" hadi \"{destination}\" ...",
    "(copy)" : "(nakili)",
    "(copy %n)" : "(nakili %n)",
    "Move cancelled" : "Uhamishaji umeghairishwa",
    "Cancelled move or copy of \"{filename}\"." : "Imesitisha uhamishaji au unakili wa \"{filename}\"",
    "Cancelled move or copy operation" : "Imesitisha operesheni ya uhamishaji au unakili",
    "Open details" : "Fungua maelezo",
    "Photos and images" : "Picha na taswira",
    "New folder creation cancelled" : "Utengenezaji wa kisanduku kipya umesitishwa",
    "This directory is unavailable, please check the logs or contact the administrator" : "Orodha haipatikani, tafadhali angalia uingiaji au wasiliana na msimamizi",
    "All folders" : "Vikasha vyote",
    "Open file sidebar" : "Fungua upau wa pembeni wa faili",
    "Search everywhere …" : "Tafuta kila mahali...",
    "Search here …" : "Tafuta hapa...",
    "Preparing …" : "Inaandaa..."
},
"nplurals=2; plural=(n != 1);");
